==> qmmp-1.5.4.tar.bz2: qmmp-1.5.4/src/app/translations/qmmp_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Niet de afspeellijst leeghalen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Begin met afspelen van huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Pauzeer huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pauzeer als er wordt gespeeld, anders spelen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Stop huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Weergeef bestandskeuze venster</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Sluit applicatie</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Verander afspeelvolume (voorbeeld: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Print volume level</source>
        <translation>Afspeelvolume printen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Mute/Restore volume</source>
        <translation>Volume dempen/herstellen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Print mute status</source>
        <translation>Dempstatus printen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Skip forward in playlist</source>
        <translation>Naar voren schuiven in afspeellijst</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Skip backwards in playlist</source>
        <translation>Naar achteren schuiven in afspeellijst</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Show/hide application</source>
        <translation>Toon/verberg programma</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Show main window</source>
        <translation>Hoofdvenster tonen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="86"/>
        <source>Display Add File dialog</source>
        <translation>Toon venster om bestanden toe te voegen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="87"/>
        <source>Display Add Directory dialog</source>
        <translation>Toon venster om mappen toe te voegen</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="108"/>
        <source>Unknown command</source>
        <translation>Onbekend commando</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="408"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Gebruik: qmmp [opties] [bestanden]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="409"/>
        <source>Options:</source>
        <translation>Opties:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="415"/>
        <source>Start qmmp with the specified user interface</source>
        <translation>Qmmp starten met opgegeven uiterlijk</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="416"/>
        <source>List all available user interfaces</source>
        <translation>Alle varianten van uiterlijk tonen</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="417"/>
        <source>Don&apos;t start the application</source>
        <translation>Niet de applicatie starten</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="418"/>
        <source>Display this text and exit</source>
        <translation>Toon deze tekst en sluit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="419"/>
        <source>Print version number and exit</source>
        <translation>Versienummer tonen en afsluiten</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="421"/>
        <source>Home page: %1</source>
        <translation>Website: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="422"/>
        <source>Development page: %1</source>
        <translation>Ontwikkelaarspagina: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="423"/>
        <source>Bug tracker: %1</source>
        <translation>Bugtracker: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="130"/>
        <location filename="../qmmpstarter.cpp" line="428"/>
        <source>Command Line Help</source>
        <translation>Opdrachtregelhulp</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="441"/>
        <source>QMMP version: %1</source>
        <translation>QMMP versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="442"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Gecompileerd met QT versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="443"/>
        <source>Using Qt version: %1</source>
        <translation>Gebruikt QT versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="446"/>
        <source>Qmmp Version</source>
        <translation>QMMP-versie</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="463"/>
        <source>User Interfaces</source>
        <translation>GebruikersInterfaces</translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/app/translations/qmmp_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Afspeellijst niet legen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Huidig nummer afspelen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Huidig nummer pauzeren</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pauzeren als er iets wordt afgespeeld; anders afspelen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Huidig nummer stopzetten</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Bestandskeuzevenster tonen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Toepassing afsluiten</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Afspeelvolume instellen (voorbeeld: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Print volume level</source>
        <translation>Afspeelvolume printen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Mute/Restore volume</source>
        <translation>Volume dempen/herstellen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Print mute status</source>
        <translation>Dempstatus printen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Skip forward in playlist</source>
        <translation>Vooruitspoelen door afspeellijst</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Skip backwards in playlist</source>
        <translation>Terugspoelen door afspeellijst</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Show/hide application</source>
        <translation>Toepassing tonen/verbergen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Show main window</source>
        <translation>Hoofdvenster tonen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="86"/>
        <source>Display Add File dialog</source>
        <translation>Venster om bestanden toe te voegen tonen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="87"/>
        <source>Display Add Directory dialog</source>
        <translation>Venster om mappen toe te voegen tonen</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="108"/>
        <source>Unknown command</source>
        <translation>Onbekende opdracht</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="408"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Gebruik: qmmp [opties] [bestanden]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="409"/>
        <source>Options:</source>
        <translation>Opties:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="415"/>
        <source>Start qmmp with the specified user interface</source>
        <translation>Qmmp starten met het opgegeven uiterlijk</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="416"/>
        <source>List all available user interfaces</source>
        <translation>Alle uiterlijke varianten tonen</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="417"/>
        <source>Don&apos;t start the application</source>
        <translation>Programma niet starten</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="418"/>
        <source>Display this text and exit</source>
        <translation>Deze tekst tonen en afsluiten</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="419"/>
        <source>Print version number and exit</source>
        <translation>Versienummer tonen en afsluiten</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="421"/>
        <source>Home page: %1</source>
        <translation>Website: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="422"/>
        <source>Development page: %1</source>
        <translation>Ontwikkelaarspagina: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="423"/>
        <source>Bug tracker: %1</source>
        <translation>Bugtracker: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="130"/>
        <location filename="../qmmpstarter.cpp" line="428"/>
        <source>Command Line Help</source>
        <translation>Opdrachtregelhulp</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="441"/>
        <source>QMMP version: %1</source>
        <translation>QMMP-versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="442"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Gebouwd met Qt-versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="443"/>
        <source>Using Qt version: %1</source>
        <translation>Gebruikte Qt-versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="446"/>
        <source>Qmmp Version</source>
        <translation>QMMP-versie</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="463"/>
        <source>User Interfaces</source>
        <translation>Uiterlijk</translation>
    </message>
</context>
</TS>
